# coding: utf-8

"""
    Mentortools Public API

    Mentortools public API service

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from public_api_server_connector_v2.models.billing_type import BillingType
from public_api_server_connector_v2.models.ipn_transaction import IpnTransaction
from public_api_server_connector_v2.models.marketplace_buyer import MarketplaceBuyer
from typing import Optional, Set
from typing_extensions import Self
from pydantic_core import to_jsonable_python

class IpnOrderPayment(BaseModel):
    """
    IpnOrderPayment
    """ # noqa: E501
    marketplace_buyer: MarketplaceBuyer = Field(description="Marketplace buyer information, including email, name, phone number and address")
    course_ids: List[StrictInt] = Field(description="List of course ids that are being paid for and should be unlocked for the buyer")
    id: Optional[StrictStr] = Field(default=None, description="External id of the order, if provided it will be prefixed with portal id, e.g. {portal_id}-{order.id}, if not provided it will be generated by the server")
    transaction: Optional[IpnTransaction] = Field(default=None, description="Transaction information, including amount and external id")
    send_email: Optional[StrictBool] = Field(default=True, description="Whether to send an email notification to the buyer after the order is created")
    billing_type: Optional[BillingType] = Field(default=None, description="Billing type for the order. Use the *_imported variants when backfilling historical orders that did not originate from a live marketplace IPN.")
    access_until: Optional[StrictInt] = Field(default=None, description="Unix timestamp in milliseconds when course access ends. Stored as access_ended_at on the entity server. Required when billing_type is subscription or subscription_imported.")
    occurred_at: Optional[StrictInt] = Field(default=None, description="Unix timestamp in milliseconds when the order occurred. If not provided, the server will use the current time.")
    __properties: ClassVar[List[str]] = ["marketplace_buyer", "course_ids", "id", "transaction", "send_email", "billing_type", "access_until", "occurred_at"]

    model_config = ConfigDict(
        validate_by_name=True,
        validate_by_alias=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(to_jsonable_python(self.to_dict()))

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of IpnOrderPayment from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of marketplace_buyer
        if self.marketplace_buyer:
            _dict['marketplace_buyer'] = self.marketplace_buyer.to_dict()
        # override the default output from pydantic by calling `to_dict()` of transaction
        if self.transaction:
            _dict['transaction'] = self.transaction.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of IpnOrderPayment from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "marketplace_buyer": MarketplaceBuyer.from_dict(obj["marketplace_buyer"]) if obj.get("marketplace_buyer") is not None else None,
            "course_ids": obj.get("course_ids"),
            "id": obj.get("id"),
            "transaction": IpnTransaction.from_dict(obj["transaction"]) if obj.get("transaction") is not None else None,
            "send_email": obj.get("send_email") if obj.get("send_email") is not None else True,
            "billing_type": obj.get("billing_type"),
            "access_until": obj.get("access_until"),
            "occurred_at": obj.get("occurred_at")
        })
        return _obj


